#!/usr/bin/ksh

###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T10
#
# (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################

#
#.$Header: /local/flexda/INSTALL/ALL/scripts/RCS/patch.sh,v 1.3 2004/11/03 01:34:07 jhe Exp $
#
# Usage:
#   -install | -uninstall    Install/Uninstall the package
#   -preview                 Display package name, destination and title
#                            information
#   -help                    Display help information
#
# Example:
#    % ./patch.sh -help
#    % ./patch.sh -preview
#    % ./patch.sh -install
#    % ./patch.sh -uninstall
#
#.

cmd=`basename $0`
PackageInfo="package.info"


#
## Preview the patch to be installed
#

    function preview {

	echo "ToolName:       $cmd"
	echo "Description:    $Description"
	echo "PatchNo:        $PatchNo"
	echo "PackageInfo:    $PackageInfo"
        echo ""
	echo "Files to be installed"
	echo "====================="

	d=0
	while (($d < ${#File[*]}))
	do
	    echo "File:           ${File[$d]}"
	    echo "TargetDir:      ${TargetDir[$d]}"
	    echo "TargetLinkDir:  ${TargetLinkDir[$d]}"
	    echo ""
	    ((d=d+1))
	done
    }


#
## Install the patch
#

    function install {

        LOCALCFG=$FLEXDAHOME/INSTALL/localhost/cfg

        cd ${InstallDir}
#	if [ ${InstallDir} != `pwd` ]
#	then
#	    echo "${cmd}: Please install the patch in the ${InstallDir}."
#	    echo "${cmd}: Refer to the \"readme\" file for instructions."
#	    echo ""
#	    exit 2
#	fi

	if [ -d backup ]
	then
	    echo "${cmd}: Patch ${PatchNo} may have been applied."
	    echo "${cmd}: Please verify."
	    echo ""
	    exit 2
	fi

	if [ ! -d ${Dir_Required} ]
	then
	    echo "${cmd}: The Following file is required before installing Patch ${PatchNo}"
	    echo "        $Pkg_Required"
	    echo ""
	    echo "${cmd}: Please contact WatchMark Technical Support for assistance"
	    echo ""
	    exit 2
	fi

	echo "${cmd}: Preparing to install patch ${PatchNo}."
	echo ""
	echo "${cmd}: Making required directories."
	echo ""

	mkdir -p -m 744 ${InstallDir}/backup
	if [ ! -d ${InstallDir}/backup ]
	then
	    echo "${cmd}: Unable to create directory ${InstallDir}/backup"
	fi

	echo "${cmd}: Backing up original files."
	echo ""

	typeset d=0
	while (( $d < ${#File[*]}))
	do
	    file=${TargetDir[$d]}/${File[$d]}
	    if [ -f ${file} ]
	    then
		cp -p ${file} ${InstallDir}/backup/${File[$d]}.bak
		chmod u+w ${file}
	    fi

	    ((d=d+1))
	done

	echo "${cmd}: Installing files."
	echo ""
	typeset d=0
	while (( $d < ${#File[*]}))
	do
	    if [ ! -d ${TargetDir[$d]} ]
	    then
		mkdir -p ${TargetDir[$d]}
	    fi

	    cp -p ${InstallDir}/${File[$d]} ${TargetDir[$d]}
	    if ([ -n "${TargetLinkDir[$d]}" ] && \
		[ ! -L ${TargetLinkDir[$d]}/${File[$d]} ])
	    then
		ln -s ${TargetDir[$d]}/${File[$d]} ${TargetLinkDir[$d]}
		chmod u-w+x ${TargetLinkDir[$d]}/${File[$d]}
	    fi

	    chmod u-w ${TargetDir[$d]}/${File[$d]}

	    ((d=d+1))
	done

        if [ -x ${InstallDir}/local.install.sh ]; then
            echo "${cmd}: Appling local install script"
            . ${InstallDir}/local.install.sh
        fi

        # Reconfigure expect path in expect scripts

        site_opts=`cat $LOCALCFG/site_opts`
        for i in COMMON $site_opts
        do

           dir=$FLEXDAHOME/${i}
           test ! -d $dir && continue

           for d in scripts
           do
               if [ -d $dir/$d ]
               then
                   echo "${cmd}: Updating expect path for $dir/$d"; echo
                   sleep 1
                   filelist=`ls $dir/$d/*.exp`
                   for f in $filelist
                   do

                       chmod u+w $f
                       temp=`echo \#\!${TPHOME} | sed 's|\/|\\\/|g'`
                       sed -e "s|.*\/flexpkg\/|$temp\/|" $f > $f.tmp
                       mv $f.tmp $f
                       chmod u-w+x $f
                    done
                fi
            done
        done

	echo "${cmd}: Done."
	echo ""
    }

#
## Uninstall the patch
#

    function uninstall {

        cd ${InstallDir}
#	if [ ${InstallDir} != $(pwd | sed 's/\/\//\//g') ]
#	then
#	    echo "${cmd}: Please install the patch in the ${InstallDir}"
#	    echo "${cmd}: Refer to the \"readme\" file for instructions"
#	    echo ""
#	    exit 2
#	fi

	if [ ! -d backup ]
	then
	    echo "${cmd}: Patch ${PatchNo} has NOT been applied."
	    echo "${cmd}: Please verify."
	    echo ""
	    exit 2
	fi

	echo "${cmd}: Preparing to remove patch ${PatchNo}."
	echo ""

	echo "${cmd}: Restoring original files."
	echo ""

	typeset d=0
	while (( $d < ${#File[*]}))
	do
            if [ -e ${TargetDir[$d]}/${File[$d]} ]; then
                chmod u+w ${TargetDir[$d]}/${File[$d]}
            fi

	    test -f ${InstallDir}/backup/${File[$d]}.bak && \
	    cp -p ${InstallDir}/backup/${File[$d]}.bak \
		${TargetDir[$d]}/${File[$d]}

	    chmod u-w ${TargetDir[$d]}/${File[$d]}

	    ((d=d+1))
	done

        if [ -x ${InstallDir}/local.uninstall.sh ]; then
            echo "${cmd}: Appling local uninstall script"
            . ${InstallDir}/local.uninstall.sh
        fi

	echo "${cmd}: Cleaning up backup directory and files."
	echo ""
	rm -rf ${InstallDir}/backup

	echo "${cmd}: Done."
    }

#
## Show help messages
#

    case $1 in
    -help|-usage)
	echo "${cmd}: Usage Information -- " 1>&2
	grep "^# " $0 | sed -e 's/^# //' 1>&2
	exit 2
    esac

#
## Locate the package.info file
#

    if [ ! -f $PackageInfo ]
    then
	echo "${cmd}: Package info file not found!"
	exit 1
    fi

#
## Source the Package Info file
#

    . ./$PackageInfo 1>&2

    InstallDir=$(echo ${FLEXDAHOME}/patches/${PatchNo} | sed 's/\/\//\//g')

    case $1 in
    -preview)
	preview
	;;

    -install)
	install
	;;

    -uninstall)
	uninstall
	;;
    esac

exit 0
